@@ -1,6 +1,6 @@
 package Log::Shiras::TapPrint;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.42.0");
+use version; our $VERSION = version->declare("v0.42.2");
 #~ use lib '../../';
 #~ use Log::Shiras::Unhide qw( :InternalTaPPrinT );
 ###InternalTaPPrinT	warn "You uncovered internal logging statements for Log::Shiras::TapPrint-$VERSION" if !$ENV{hide_warn};
@@ -13,6 +13,8 @@ Moose::Exporter->setup_import_methods(
 use MooseX::Types::Moose qw( HashRef );
 use Carp 'longmess';
 use IO::Callback;
+use strict;
+use warnings;
 use lib '../../../lib',;
 use Log::Shiras::Switchboard;
 my	$switchboard = Log::Shiras::Switchboard->instance;
