@@ -1,6 +1,6 @@
 package Log::Shiras::Types;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.42.0");
+use version; our $VERSION = version->declare("v0.42.2");
 #~ use lib '../../';
 #~ use Log::Shiras::Unhide qw( :InternalTypeSShirasFormat :InternalTypeSFileHash :InternalTypeSReportObject :InternalTypeSHeadeR);
 ###InternalTypeSShirasFormat	use Data::Dumper;
@@ -28,6 +28,8 @@ use MooseX::Types -declare =>[qw(
 	)];#
 #~ use YAML::Any qw( Dump LoadFile );
 use JSON::XS;
+use strict;
+use warnings;
 use lib '../../../lib', '../../lib';
 
 #########1 Package Variables  3#########4#########5#########6#########7#########8#########9
